IR Datasets
===========

XPMIR provides an interface to the `IR Datasets <https://ir-datasets.com/>`_ library.
The list below is provided as a reference, but might not be up-to-date if your
version of `ir-datasets` is more ancient or newer than the one used at generation time.

List of configurations
----------------------

.. autoxpmconfig:: xpmir.datasets.irds.data.AdhocTopics
.. autoxpmconfig:: xpmir.datasets.irds.data.AdhocDocuments
.. autoxpmconfig:: xpmir.datasets.irds.data.AdhocAssessments

List of datasets
----------------------

.. dm:repository:: irds
